dohlee.gene module — dohlee 0.1.10 documentation

# dohlee.gene module

`dohlee.gene.` `get_first_item`(items)

  Return the first item of items. If ‘items’ is a single value, just return it.

  Parameters: | items (list/value) – A list of items or a single value.
  Returns: | The first item of items.

`dohlee.gene.` `ensg2symbol`(ensembl_ids)

  Convert Ensembl gene ids into gene symbols.

  Parameters: | ensembl_ids (list) – A list of Ensembl IDs to be converted.
  Returns: | A list of HGNC symbols, which is the result of best conversion of given Ensembl IDs.

`dohlee.gene.` `symbol2ensg`(symbols=None)

  Convert gene symbols into Ensembl gene ids.

  Parameters: | symbols (list) – A list of HGNC symbols to be converted.
  Returns: | A list of Ensembl gene symbols(ENSG symbols).